<?php

namespace HelpieFaq\Features\Faq\Dynamic_Widget;

if (!defined('ABSPATH')) {
    exit;
} // Exit if accessed directly

if (!class_exists('HelpieFaq\Features\Faq\Dynamic_Widget\Faq_Model')) {
    class Faq_Model
    {
        public $top_level = '';

        public function __construct()
        {
            $this->faq_repo = new \HelpieFaq\Includes\Repos\Faq_Repo();
            $this->style_config = new \HelpieFaq\Features\Faq\Style_Config_Model();
            $this->fields_model = new \HelpieFaq\Features\Faq\Dynamic_Widget\Fields_Model();
        }

        public function get_viewProps($args)
        {

            // $args = $this->get_default_args($args);
            /* Set $this->top_level */

            /* Get top level item objs */
            if ($this->top_level == 'categories') {
                $items_wp_objs = $this->faq_repo->get_faq_categories($args);
            } else {
                $items_wp_objs = $this->faq_repo->get_faqs($args);
            }

            // FAQ Categories Props
            $items_props = $this->get_items_props($items_wp_objs, $args);

            if ($this->top_level == 'categories') {
                // Remove empty category faqs
                $items_props = $this->get_non_empty_items_props($items_props);
            }

            $viewProps = array(
                'collection' => $this->get_collection_props($args),
                'items' => $items_props,
            );

            // error_log('viewProps : ' . print_r($viewProps, true));

            return $viewProps;
        }

        public function get_style_config()
        {
            return $this->style_config->get_config();
        }

        public function get_fields()
        {
            return $this->fields_model->get_fields();
        }

        public function get_default_args()
        {
            // First Layer: Defaults
            $default_settings_args = $this->fields_model->get_default_args();
            // Second Layer: Helpie FAQ Settings Values
            $settings = new \HelpieFaq\Includes\Settings\Getters\Getter();
            $user_defined_settings_args = $settings->get_settings();
            // Third Layer: Interpreted Settings
            $interpreted_settings_args = $this->get_interpreted_settings_args($user_defined_settings_args);
            $args = array_merge($default_settings_args, $user_defined_settings_args, $interpreted_settings_args);
            return $args;
        }

        public function get_field($field_name)
        {
            $fields = $this->get_fields();
            return $fields[$field_name];
        }

        protected function get_items_props($faq_wp_objs, $args)
        {
            $itemsProps = array();
            $count = 0;

            foreach ($faq_wp_objs as $faq_wp_obj) {
                // $faq_wp_obj = new \Helpie\Includes\Models\Kb_Article($article);
                if ($this->top_level == 'categories') {
                    $itemsProps[$count] = $this->map_domain_props_category($faq_wp_obj);
                    $term_id = $itemsProps[$count]['term_id'];

                    $cat_faq_args = array_merge($args, array('categories' => $term_id));
                    $wp_faqs_children = $this->faq_repo->get_faqs($cat_faq_args);

                    $this->top_level = 'articles';
                    $itemsProps[$count]['children'] = $this->get_items_props($wp_faqs_children, $args);
                    $this->top_level = 'categories';
                } else {
                    $itemsProps[$count] = $this->map_domain_props_to_view_item_props($faq_wp_obj, $args);
                }

                $count++;
            }

            return $itemsProps;
        }

        protected function map_domain_props_category($faq_wp_obj)
        {

            $itemProps = array(
                'title' => $faq_wp_obj->name,
                'content' => $faq_wp_obj->description,
                'term_id' => $faq_wp_obj->term_id,
                'count' => get_term_meta($faq_wp_obj->term_id, 'click_counter', false),
            );

            // error_log('$itemProps : ' . print_r($itemProps, true));

            return $itemProps;
        }

        protected function map_domain_props_to_view_item_props($faq_wp_obj, $args)
        {

            $itemProps = array(
                'title' => $faq_wp_obj->post_title,
                'content' => $faq_wp_obj->post_content,
                'post_id' => $faq_wp_obj->ID,
                'count' => get_post_meta($faq_wp_obj->ID, 'click_counter', false),
            );

            $search_tags_enabled = (isset($args['search_by_tags']) && $args['search_by_tags'] == 1) ? true : false;
            if (hf_fs()->is__premium_only() && $search_tags_enabled) {
                $tags = new \HelpieFaq\Features\Faq\Tags();
                $itemProps = $tags->get_tags($itemProps);
            }

            // error_log('$itemProps : ' . print_r($itemProps, true));
            return $itemProps;
        }

        protected function get_collection_props($args)
        {

            $collectionProps = array(
                'context' => $this->get_context(),
                'title' => "FAQ Added Via Elementor",
                'display_mode' => 'simple_accordion',
            );

            $collectionProps = array_merge($collectionProps, $args);

            return $collectionProps;
        }

        protected function show_user_name()
        {
            return $this->settings->single_page->show_user_name();
        }

        protected function get_context()
        {
            $context = array();
            // Woo Product
            if (is_singular('product') && is_single(get_the_ID())) {
                $context['woo-product'] = get_queried_object()->ID;
            } elseif (is_tax('helpdesk_category')) {
                $context['kb-category'] = get_queried_object()->term_id;
            }
            // Wiki KB Category

            return $context;
        }

        public function get_non_empty_items_props($props)
        {

            foreach ($props as $key => $prop) {
                if (empty($prop['children'])) {
                    unset($props[$key]);
                }
            }
            $props = array_values($props); // 'reindex' array (edited)

            return $props;
        }

        public function get_interpreted_settings_args(array $settings_args)
        {
            $settings_handler = new \HelpieFaq\Features\Faq\Settings_Handlers();
            $args = $settings_handler->get_interpreted_settings_args($settings_args);
            return $args;
        }
    }
}